var indexSectionsWithContent =
{
  0: "abcdefghilmnopqrstvx",
  1: "afimsx",
  2: "mqs",
  3: "abcdefghilmnoprstvx",
  4: "ehmnvx",
  5: "x",
  6: "s"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "groups",
  6: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Modules",
  6: "Pages"
};

